@@ -111,12 +111,21 @@ If prefix-argument directly DETACH from the session."
                        (seq-filter (lambda (it) (eq 'active (detached--determine-session-state it)))))))
     (detached-completing-read sessions)))
 
+(cl-defmethod detached--detach-session ((_mode (derived-mode eshell-mode)))
+  "Detach from session when MODE is `eshell-mode'."
+  (when-let ((active-session (eq 'active (detached--determine-session-state detached--buffer-session)))
+             (dtach-process (detached-eshell--get-dtach-process)))
+    (setq detached--buffer-session nil)
+    (process-send-string dtach-process
+                         detached--dtach-detach-character)))
+
 ;;;; Minor mode
 
 (defvar detached-eshell-mode-map
   (let ((map (make-sparse-keymap)))
     (define-key map (kbd "<S-return>") #'detached-eshell-send-input)
     (define-key map (kbd "<C-return>") #'detached-eshell-attach-session)
+    (define-key map (kbd "C-c C-.") #'detached-describe-session)
     (define-key map (kbd detached-detach-key) #'detached-detach-session)
     map)
   "Keymap for `detached-eshell-mode'.")
