@@ -5,7 +5,7 @@
 ;; Author: Niklas Eklund <niklas.eklund@posteo.net>
 ;; Maintainer: detached.el Development <~niklaseklund/detached.el@lists.sr.ht>
 ;; URL: https://sr.ht/~niklaseklund/detached.el/
-;; Version: 0.9.1
+;; Version: 0.9.2
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience processes
 
@@ -53,20 +53,18 @@
 (require 'subr-x)
 (require 'tramp)
 
-(declare-function detached-eshell--get-dtach-process "detached-eshell")
-
 ;;;; Variables
 
 ;;;;; Customizable
 
 (defcustom detached-session-directory
-  (expand-file-name "detached/sessions" user-emacs-directory)
+  (locate-user-emacs-file "detached/sessions")
   "The directory to store sessions."
   :type 'string
   :group 'detached)
 
 (defcustom detached-db-directory
-  (expand-file-name "detached" user-emacs-directory)
+  (locate-user-emacs-file "detached")
   "The directory to store the `detached' database."
   :type 'string
   :group 'detached)
@@ -81,6 +79,21 @@
   :type 'string
   :group 'detached)
 
+(defcustom detached-grep-program "grep"
+  "The name of the grep program."
+  :type 'string
+  :group 'detached)
+
+(defcustom detached-tee-program "tee"
+  "The name of the tee program."
+  :type 'string
+  :group 'detached)
+
+(defcustom detached-script-program "script"
+  "The name of the script program."
+  :type 'string
+  :group 'detached)
+
 (defcustom detached-shell-program shell-file-name
   "Path to the shell to run the dtach command in."
   :type 'string
@@ -186,6 +199,20 @@ If set to a non nil value the latest entry to
   :type 'float
   :group 'detached)
 
+(defcustom detached-open-session-display-buffer-action
+  '(display-buffer-pop-up-window)
+  "The action used to display a detached session."
+  :group 'detached
+  :type 'sexp)
+
+(defcustom detached-session-info-buffer-action
+  '(display-buffer-in-side-window
+                 (side . bottom)
+                 (dedicated . t))
+  "The action used to display a information about a detached session."
+  :group 'detached
+  :type 'sexp)
+
 ;;;;; Public
 
 (defvar detached-enabled nil)
@@ -209,13 +236,22 @@ Valid values are: create, new and attach")
 (defvar detached-compile-session-hooks nil
   "Hooks to run when compiling a session.")
 
+(defvar detached-update-db-hooks nil
+  "Hooks to run when the database is updated.")
+
 (defvar detached-metadata-annotators-alist nil
   "An alist of annotators for metadata.")
 
-(defconst detached-session-version "0.9.1.0"
+(defvar detached-session-annotation nil
+  "An annotation string.")
+
+(defconst detached-session-version "0.9.2.0"
   "The version of `detached-session'.
 This version is encoded as [package-version].[revision].")
 
+(defconst detached-minimum-session-version "0.9.1.1"
+  "The version of `detached-session' that the package is compatible with.")
+
 ;;;;; Faces
 
 (defgroup detached-faces nil
@@ -263,6 +299,15 @@ This version is encoded as [package-version].[revision].")
   '((t :inherit detached-state-face))
   "Face used to highlight marked session in `detached-list-mode'.")
 
+(defface detached-annotation-face
+  '((t :inherit font-lock-comment-face))
+  "Face used to highlight the annotation of a session in `eldoc-mode'.")
+
+(defface detached-uninitialized-face
+  '((t :inherit font-lock-comment-face))
+  "Face used to highlight that a session is uninitialized.")
+
+
 ;;;;; Private
 
 (defvar detached--sessions-initialized nil
@@ -298,6 +343,9 @@ This version is encoded as [package-version].[revision].")
 (defvar detached--annotation-widths nil
   "An alist of widths to use for annotation.")
 
+(defvar detached--update-database t
+  "Update the database when value is t.")
+
 (defconst detached--shell-command-buffer "*Detached Shell Command*"
   "Name of the `detached-shell-command' buffer.")
 
@@ -325,6 +373,7 @@ This version is encoded as [package-version].[revision].")
   (degraded nil :read-only t)
   (env nil :read-only t)
   (action nil :read-only t)
+  (annotation)
   (time nil)
   (status nil)
   (size nil)
@@ -363,6 +412,8 @@ Optionally SUPPRESS-OUTPUT if prefix-argument is provided."
   (let* ((detached-session-origin (or detached-session-origin 'shell-command))
          (detached-session-action (or detached-session-action
                                       detached-shell-command-session-action))
+         (detached-session-mode (or detached-session-mode
+                                 (if suppress-output 'create 'create-and-attach)))
          (detached--current-session (detached-create-session command)))
     (detached-start-session command suppress-output)))
 
@@ -406,8 +457,10 @@ The session is compiled by opening its output and enabling
             (setq detached--buffer-session session)
             (setq-local font-lock-defaults '(compilation-mode-font-lock-keywords t)))
           (font-lock-mode)
-          (read-only-mode))
-        (pop-to-buffer buffer-name)))))
+          (read-only-mode)
+          (goto-char (point-max)))
+        (select-window
+         (display-buffer buffer-name detached-open-session-display-buffer-action))))))
 
 ;;;###autoload
 (defun detached-rerun-session (session &optional suppress-output)
@@ -418,7 +471,8 @@ The session is compiled by opening its output and enabling
   (when (detached-valid-session session)
     (let* ((default-directory
              (detached--session-working-directory session))
-           (detached-session-mode (detached--session-initial-mode session))
+           (detached-session-mode (or detached-session-mode
+                                      (detached--session-initial-mode session)))
            (detached-session-action (detached--session-action session))
            (command (detached--session-command session)))
       (if suppress-output
@@ -427,6 +481,20 @@ The session is compiled by opening its output and enabling
             (funcall run-fun command)
           (detached-start-session command))))))
 
+(defun detached-describe-session ()
+  "Describe current session."
+  (interactive)
+  (when-let* ((session (detached--get-session major-mode))
+              (buffer (get-buffer-create "*detached-session-info*"))
+              (window (display-buffer buffer detached-session-info-buffer-action)))
+    (select-window window)
+    (with-current-buffer buffer
+      (erase-buffer)
+      (insert
+       (string-trim
+        (detached--session-header session)))
+      (goto-char (point-min)))))
+
 ;;;###autoload
 (defun detached-attach-session (session)
   "Attach to SESSION."
@@ -458,8 +526,7 @@ The session is compiled by opening its output and enabling
   "Copy SESSION's command."
   (interactive
    (list (detached-completing-read (detached-get-sessions))))
-  (when (detached-valid-session session)
-    (kill-new (detached--session-command session))))
+  (kill-new (detached--session-command session)))
 
 ;;;###autoload
 (defun detached-insert-session-command (session)
@@ -514,7 +581,8 @@ Optionally DELETE the session if prefix-argument is provided."
                 (detached-log-mode))
               (setq detached--buffer-session session)
               (goto-char (point-max)))
-            (pop-to-buffer buffer-name))
+            (select-window
+             (display-buffer buffer-name detached-open-session-display-buffer-action)))
         (message "Detached can't find file: %s" file-path)))))
 
 ;;;###autoload
@@ -565,31 +633,8 @@ This command is only activated if `detached--buffer-session' is an
 active session.  For sessions created with `detached-compile' or
 `detached-shell-command', the command will also kill the window."
   (interactive)
-  (if (detached-session-p detached--buffer-session)
-      (if-let ((command-or-compile
-                (cond ((string-match detached--shell-command-buffer (buffer-name)) t)
-                      ((string-match "\*detached-compilation" (buffer-name)) t)
-                      ((eq major-mode 'detached-log-mode) t)
-                      (t nil))))
-          ;; `detached-shell-command' or `detached-compile'
-          (let ((kill-buffer-query-functions nil))
-            (when-let ((process (get-buffer-process (current-buffer))))
-              (comint-simple-send process detached--dtach-detach-character)
-              (message "[detached]"))
-            (setq detached--buffer-session nil)
-            (kill-buffer-and-window))
-        (if (eq 'active (detached--determine-session-state detached--buffer-session))
-            ;; `detached-eshell'
-            (if-let ((process (and (eq major-mode 'eshell-mode)
-                                   (detached-eshell--get-dtach-process))))
-                (progn
-                  (setq detached--buffer-session nil)
-                  (process-send-string process detached--dtach-detach-character))
-              ;; `detached-shell'
-              (let ((process (get-buffer-process (current-buffer))))
-                (comint-simple-send process detached--dtach-detach-character)
-                (setq detached--buffer-session nil)))
-          (message "No active detached-session found in buffer.")))
+  (if-let ((has-session (detached-session-p detached--buffer-session)))
+      (detached--detach-session major-mode)
     (message "No detached-session found in buffer.")))
 
 ;;;###autoload
@@ -622,6 +667,7 @@ active session.  For sessions created with `detached-compile' or
                                     :initial-mode detached-session-mode
                                     :time `(:start ,(time-to-seconds (current-time)) :end 0.0 :duration 0.0 :offset 0.0)
                                     :status '(unknown . 0)
+                                    :annotation detached-session-annotation
                                     :size 0
                                     :directory (detached--get-session-directory)
                                     :env (detached--env command)
@@ -648,25 +694,30 @@ Optionally SUPPRESS-OUTPUT."
                (or detached--current-session
                    (detached-create-session command))))
           (setq detached-enabled nil)
-          (if detached-local-session
-              (apply #'start-process-shell-command
-                     `("detached" nil ,(detached--dtach-command detached--current-session t)))
-            (apply #'start-file-process-shell-command
-                   `("detached" nil ,(detached--dtach-command detached--current-session t)))))
+          (detached-start-detached-session
+           detached--current-session))
       (cl-letf* ((detached-session-mode 'create-and-attach)
                  (detached--current-session
                   (or detached--current-session
                       (detached-create-session command)))
                  ((symbol-function #'set-process-sentinel) #'ignore)
-                 (buffer (get-buffer-create detached--shell-command-buffer))
+                 (buffer (detached--generate-buffer detached--shell-command-buffer
+                                                    (lambda (buffer)
+                                                      (not (get-buffer-process buffer)))))
                  (command (detached--shell-command detached--current-session t)))
-        (when (get-buffer-process buffer)
-          (setq buffer (generate-new-buffer (buffer-name buffer))))
         (setq detached-enabled nil)
         (funcall #'async-shell-command command buffer)
         (with-current-buffer buffer
           (setq detached--buffer-session detached--current-session))))))
 
+(defun detached-start-detached-session (session)
+  "Start SESSION in detached mode."
+  (if detached-local-session
+      (apply #'start-process-shell-command
+             `("detached" nil ,(detached--dtach-command session t)))
+    (apply #'start-file-process-shell-command
+           `("detached" nil ,(detached--dtach-command session t)))))
+
 (defun detached-session-candidates (sessions)
   "Return an alist of SESSIONS candidates."
   (when sessions
@@ -735,9 +786,11 @@ Optionally SUPPRESS-OUTPUT."
     ;; Initialize accessible sessions
     (let ((detached--current-emacsen (detached--active-detached-emacsen)))
       (detached--update-detached-emacsen)
-      (thread-last (detached--db-get-sessions)
-                   (seq-filter #'detached--session-accessible-p)
-                   (seq-do #'detached--initialize-session)))))
+      (let ((detached--update-database nil))
+        (thread-last (detached--db-get-sessions)
+                     (seq-filter #'detached--session-accessible-p)
+                     (seq-do #'detached--initialize-session)))
+      (detached--db-update-sessions))))
 
 (defun detached-valid-session (session)
   "Ensure that SESSION is valid.
@@ -800,9 +853,12 @@ This function uses the `notifications' library."
 (defun detached-get-sessions ()
   "Return as initialized sessions as possible."
   ;; Try to initialize unknown sessions
-  (thread-last (detached--uninitialized-sessions)
-               (seq-filter #'detached--session-accessible-p)
-               (seq-do #'detached--initialize-session))
+  (when-let* ((detached--update-database nil)
+              (initialized-sessions
+               (thread-last (detached--uninitialized-sessions)
+                            (seq-filter #'detached--session-accessible-p)
+                            (seq-do #'detached--initialize-session))))
+    (detached--db-update-sessions))
   (detached--db-get-sessions))
 
 (defun detached-shell-command-attach-session (session)
@@ -812,7 +868,7 @@ This function uses the `notifications' library."
          (inhibit-message t))
     (cl-letf* (((symbol-function #'set-process-sentinel) #'ignore)
                (buffer (get-buffer-create detached--shell-command-buffer))
-               (default-directory (detached--session-working-directory session))
+               (default-directory (detached--session-directory session))
                (command (detached--shell-command session t)))
       (when (get-buffer-process buffer)
         (setq buffer (generate-new-buffer (buffer-name buffer))))
@@ -834,6 +890,10 @@ This function uses the `notifications' library."
 
 ;;;;; Other
 
+(cl-defgeneric detached--get-session (_mode)
+  "Return session."
+  detached--buffer-session)
+
 (cl-defgeneric detached--shell-command (entity &optional concat)
   "Return shell command for ENTITY optionally CONCAT.")
 
@@ -1045,6 +1105,7 @@ Optionally CONCAT the command return command into a string."
      ,(format "Host: %s" (car (detached--session-host session)))
      ,(format "Id: %s" (symbol-name (detached--session-id session)))
      ,(format "Status: %s" (car (detached--session-status session)))
+     ,(format "Annotation: %s" (if-let ((annotation (detached--session-annotation session))) annotation ""))
      ,(format "Exit-code: %s" (cdr (detached--session-status session)))
      ,(format "Metadata: %s" (detached--metadata-str session))
      ,(format "Created at: %s" (detached--creation-str session))
@@ -1078,17 +1139,6 @@ Optionally CONCAT the command return command into a string."
   "Return the session associated with ITEM."
   (cdr (assoc item detached--session-candidates)))
 
-(defun detached--validate-unknown-sessions ()
-  "Validate `detached' sessions with state unknown."
-  (thread-last (detached--db-get-sessions)
-               (seq-filter (lambda (it) (eq 'unknown (detached--session-state it))))
-               (seq-filter #'detached--session-accessible-p)
-               (seq-do (lambda (it)
-                         (if (detached--session-missing-p it)
-                             (detached--db-remove-entry it)
-                           (setf (detached--session-state it) 'active)
-                           (detached--db-update-entry it t))))))
-
 (defun detached--create-session-validator (session)
   "Create a function to validate SESSION.
 
@@ -1138,7 +1188,8 @@ Optionally make the path LOCAL to host."
 (defun detached--session-output (session)
   "Return content of SESSION's output."
   (let* ((filename (detached--session-file session 'log))
-         (detached-message (rx (regexp "\n.detached-exit-code:.*"))))
+         (detached-message
+          (rx (regexp "\n.*\\[detached-exit-code: .*\\]"))))
     (with-temp-buffer
       (insert-file-contents filename)
       (detached--maybe-watch-session session)
@@ -1176,6 +1227,40 @@ Optionally make the path LOCAL to host."
       detached-session-directory
     (concat (file-remote-p default-directory) detached-session-directory)))
 
+(cl-defgeneric detached--detach-session (_mode)
+  "Default implementation."
+  (message "`detached' doesn't know how to detach from a session in this mode"))
+
+(cl-defmethod detached--detach-session ((_mode (derived-mode detached-log-mode)))
+  "Detach from session when MODE is `detached-log-mode'."
+  (detached--quit-session-buffer))
+
+(cl-defmethod detached--detach-session ((_mode (derived-mode shell-mode)))
+  "Detach from session when MODE is `shell-mode'."
+  (detached--detach-from-comint-process)
+  (when (string-match detached--shell-command-buffer (buffer-name))
+    (detached--quit-session-buffer)))
+
+(cl-defmethod detached--detach-session ((_mode (derived-mode comint-mode)))
+  "Detach from session when MODE is `comint-mode'."
+  (detached--detach-from-comint-process)
+  (detached--quit-session-buffer))
+
+(defun detached--detach-from-comint-process ()
+  "Detach from the underlying `comint' process."
+  (when-let ((active-session (eq 'active (detached--determine-session-state detached--buffer-session)))
+             (dtach-process (get-buffer-process (current-buffer))))
+    (setq detached--buffer-session nil)
+    (comint-simple-send dtach-process detached--dtach-detach-character)))
+
+(defun detached--quit-session-buffer ()
+  "Quit session buffer."
+  (message "[detached]")
+  (let ((kill-buffer-query-functions nil))
+    (if (= (length (window-list)) 1)
+        (kill-buffer)
+      (kill-buffer-and-window))))
+
 ;;;;; Database
 
 (defun detached--db-initialize ()
@@ -1185,9 +1270,11 @@ Optionally make the path LOCAL to host."
       (with-temp-buffer
         (insert-file-contents db)
         (cl-assert (bobp))
-        (when (string= (detached--db-session-version) detached-session-version)
+        (if (detached--verify-db-compatibility)
           (setq detached--sessions
-                (read (current-buffer))))))))
+                (read (current-buffer)))
+          (warn "Detached database has version %s while minimum version is %s"
+                (detached--db-session-version) detached-minimum-session-version))))))
 
 (defun detached--db-session-version ()
   "Return `detached-session-version' from database."
@@ -1199,7 +1286,8 @@ Optionally make the path LOCAL to host."
 (defun detached--db-insert-entry (session)
   "Insert SESSION into `detached--sessions' and update database."
   (push `(,(detached--session-id session) . ,session) detached--sessions)
-  (detached--db-update-sessions))
+  (when detached--update-database
+    (detached--db-update-sessions)))
 
 (defun detached--db-remove-entry (session)
   "Remove SESSION from `detached--sessions', delete log and update database."
@@ -1208,12 +1296,13 @@ Optionally make the path LOCAL to host."
       (delete-file log)))
   (setq detached--sessions
         (assq-delete-all (detached--session-id session) detached--sessions))
-  (detached--db-update-sessions))
+  (when detached--update-database
+    (detached--db-update-sessions)))
 
-(defun detached--db-update-entry (session &optional update)
-  "Update SESSION in `detached--sessions' optionally UPDATE database."
+(defun detached--db-update-entry (session)
+  "Update SESSION in `detached--sessions' and the database."
   (setf (alist-get (detached--session-id session) detached--sessions) session)
-  (when update
+  (when detached--update-database
     (detached--db-update-sessions)))
 
 (defun detached--db-get-session (id)
@@ -1226,6 +1315,7 @@ Optionally make the path LOCAL to host."
 
 (defun detached--db-update-sessions ()
   "Write `detached--sessions' to database."
+  (run-hooks 'detached-update-db-hooks)
   (let ((db (expand-file-name "detached-sessions.db" detached-db-directory)))
     (with-temp-file db
       (insert (format ";; Detached Session Version: %s\n\n" detached-session-version))
@@ -1293,11 +1383,42 @@ Optionally make the path LOCAL to host."
   (if (detached--uninitialized-session-p session)
       (progn
         (detached--initialize-session session)
+        (detached--db-update-sessions)
         (detached--db-get-session (detached--session-id session)))
     session))
 
+(defun detached--verify-db-compatibility ()
+  "Verify that the database version is compatible with the package."
+  (let ((minimum-version
+         (detached--decode-version-string detached-minimum-session-version))
+        (db-version
+         (detached--decode-version-string (detached--db-session-version))))
+    (if (> (plist-get db-version :major) (plist-get minimum-version :major))
+        t
+      (when (= (plist-get db-version :major) (plist-get minimum-version :major))
+        (if (> (plist-get db-version :minor) (plist-get minimum-version :minor))
+            t
+          (when (= (plist-get db-version :minor) (plist-get minimum-version :minor))
+            (if (> (plist-get db-version :patch) (plist-get minimum-version :patch))
+                t
+              (when (= (plist-get db-version :patch) (plist-get minimum-version :patch))
+                (>= (plist-get db-version :revision) (plist-get minimum-version :revision))))))))))
+
 ;;;;; Other
 
+(defun detached--decode-version-string (version)
+  "Return a decode property list of VERSION."
+  (let ((version-regexp
+         (rx (group (one-or-more digit)) "."
+             (group (one-or-more digit)) "."
+             (group (one-or-more digit)) "."
+             (group (one-or-more digit)))))
+    (when (string-match version-regexp version)
+      `(:major ,(string-to-number (match-string 1 version))
+        :minor ,(string-to-number (match-string 2 version))
+        :patch ,(string-to-number (match-string 3 version))
+        :revision ,(string-to-number (match-string 4 version))))))
+
 (defun detached--dtach-arg ()
   "Return dtach argument based on `detached-session-mode'."
   (pcase detached-session-mode
@@ -1306,13 +1427,14 @@ Optionally make the path LOCAL to host."
     ('attach "-a")
     (_ (error "`detached-session-mode' has an unknown value"))))
 
-(defun detached--session-state-transition-update (session)
-  "Update SESSION due to state transition."
-  ;; Update session
+(defun detached--session-state-transition-update (session &optional approximate)
+  "Update SESSION due to state transition.
+
+Optionally specify if the end-time should be APPROXIMATE or not."
   (let ((session-size (file-attribute-size
                        (file-attributes
                         (detached--session-file session 'log))))
-        (session-time (detached--update-session-time session) )
+        (session-time (detached--update-session-time session approximate))
         (status-fun (or (plist-get (detached--session-action session) :status)
                         #'detached-session-exit-code-status)))
     (setf (detached--session-size session) session-size)
@@ -1324,7 +1446,7 @@ Optionally make the path LOCAL to host."
   (funcall detached-notification-function session)
 
   ;; Update session in database
-  (detached--db-update-entry session t)
+  (detached--db-update-entry session)
 
   ;; Execute callback
   (when-let ((callback (plist-get (detached--session-action session) :callback)))
@@ -1355,7 +1477,7 @@ If SESSION is degraded fallback to a command that doesn't rely on tee."
          (redirect
           (if (detached--session-degraded session)
               (format "&> %s" log)
-            (format "2>&1 | tee %s" log)))
+            (format "2>&1 | %s %s" detached-tee-program log)))
          (shell (format "%s -c" detached-shell-program))
          (command
           (shell-quote-argument
@@ -1372,8 +1494,8 @@ If SESSION is degraded fallback to a command that doesn't rely on tee."
 (defun detached--get-terminal-data-command ()
   "Return terminal data command."
   (pcase detached-terminal-data-command
-    ('gnu/linux "script --quiet --flush --return --command \"%s\" /dev/null")
-    ('darwin "script -F -q /dev/null %s")
+    ('gnu/linux (concat detached-script-program " --quiet --flush --return --command \"%s\" /dev/null"))
+    ('darwin (concat detached-script-program " -F -q /dev/null %s"))
     ((and (pred stringp) command) command)
     (_ (error "Unable to determine script command, set `detached-terminal-data-command' properly"))))
 
@@ -1387,7 +1509,9 @@ If SESSION is degraded fallback to a command that doesn't rely on tee."
 
 (defun detached--host ()
   "Return a cons with (host . type)."
-  (let ((remote (file-remote-p default-directory)))
+  (let ((remote
+         (and (file-remote-p default-directory)
+          (not detached-local-session))))
     `(,(if remote (file-remote-p default-directory 'host) (system-name)) . ,(if remote 'remote 'local))))
 
 (defun detached--update-session-time (session &optional approximate)
@@ -1483,12 +1607,12 @@ session and trigger a state transition."
 
   (if (detached--active-session-p session)
       (if (detached--state-transition-p session)
-          (detached--session-state-transition-update session)
-        (detached--db-update-entry session t)
+          (detached--session-state-transition-update session 'approximate)
+        (detached--db-update-entry session)
         (detached--watch-session-directory (detached--session-directory session)))
     (if (detached--session-missing-p session)
         (detached--db-remove-entry session)
-      (detached--db-update-entry session t))))
+      (detached--db-update-entry session))))
 
 (defun detached--uninitialized-sessions ()
   "Return a list of uninitialized sessions."
@@ -1536,6 +1660,22 @@ If event is cased by an update to the `detached' database, re-initialize
                                     (seq-max)
                                     (min width)))))
 
+(defun detached--generate-buffer (name reuse-p &optional number)
+  "Reuse or generate new buffer like built-in function `generate-new-buffer'.
+NAME is used the same way as `generate-new-buffer' but if a buffer which
+REUSE-P for buffer returns nil, return buffer instead.
+
+NUMBER is used internally for recursive calls, but can be used to
+start searching at NUMBER offset."
+  (let* ((buffer-name (if number
+                          (format "%s<%d>" name number)
+                        name))
+         (buffer (get-buffer buffer-name))
+         (number (or number 1)))
+    (if (and buffer (not (funcall reuse-p buffer)))
+        (detached--generate-buffer name reuse-p (1+ number))
+      (get-buffer-create buffer-name))))
+
 (defun detached--metadata-git-branch ()
   "Return current git branch."
   (let ((args '("symbolic-ref" "HEAD" "--short")))
@@ -1618,6 +1758,7 @@ If event is cased by an update to the `detached' database, re-initialize
 (defvar detached-shell-mode-map
   (let ((map (make-sparse-keymap)))
     (define-key map (kbd detached-detach-key) #'detached-detach-session)
+    (define-key map (kbd "C-c C-.") #'detached-describe-session)
     map)
   "Keymap for `detached-shell-mode'.")
 
@@ -1638,6 +1779,7 @@ If event is cased by an update to the `detached' database, re-initialize
 (defvar detached-log-mode-map
   (let ((map (make-sparse-keymap)))
     (define-key map (kbd detached-detach-key) #'detached-detach-session)
+    (define-key map (kbd "C-c C-.") #'detached-describe-session)
     map)
   "Keymap for `detached-log-mode'.")
 
